summaryrefslogtreecommitdiffstats
path: root/generic/tkMenu.c
diff options
context:
space:
mode:
authorjan.nijtmans <nijtmans@users.sourceforge.net>2022-09-20 14:30:30 (GMT)
committerjan.nijtmans <nijtmans@users.sourceforge.net>2022-09-20 14:30:30 (GMT)
commit7f221a2df1a014ecc7105bc28747db0f495418c6 (patch)
tree0d86970a3b2e7db71cf7fd9b759a32c02df2816a /generic/tkMenu.c
parent6048e7ee1e5e601420abe15c5e0c83af9f9aa9db (diff)
downloadtk-7f221a2df1a014ecc7105bc28747db0f495418c6.zip
tk-7f221a2df1a014ecc7105bc28747db0f495418c6.tar.gz
tk-7f221a2df1a014ecc7105bc28747db0f495418c6.tar.bz2
typo Tk_SetWindowMenuBar -> Tk_SetWindowMenubar. (TIP #606 and documentation was correct)
Diffstat (limited to 'generic/tkMenu.c')
-rw-r--r--generic/tkMenu.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/generic/tkMenu.c b/generic/tkMenu.c
index 4730575..3c731b8 100644
--- a/generic/tkMenu.c
+++ b/generic/tkMenu.c
@@ -569,14 +569,14 @@ Tk_MenuObjCmd(
while (topLevelListPtr != NULL) {
/*
* Need to get the next pointer first. Tk_SetWindowMenuBar changes
* the list, so that the next pointer is different after calling
* it.
*/
nextPtr = topLevelListPtr->nextPtr;
listtkwin = topLevelListPtr->tkwin;
- Tk_SetWindowMenuBar(menuPtr->interp, listtkwin,
+ Tk_SetWindowMenubar(menuPtr->interp, listtkwin,
Tk_PathName(menuPtr->tkwin), Tk_PathName(menuPtr->tkwin));
topLevelListPtr = nextPtr;
}
@@ -3129,7 +3129,7 @@ TkNewMenuName(
/*
*----------------------------------------------------------------------
*
- * Tk_SetWindowMenuBar --
+ * Tk_SetWindowMenubar --
*
* Associates a menu with a window. Called by ConfigureFrame in in
* response to a "-menu .foo" configuration option for a top level.
@@ -3145,7 +3145,7 @@ TkNewMenuName(
*/
void
-Tk_SetWindowMenuBar(
+Tk_SetWindowMenubar(
Tcl_Interp *interp, /* The interpreter the toplevel lives in. */
Tk_Window tkwin, /* The toplevel window. */
const char *oldMenuName, /* The name of the menubar previously set in
@@ -569,14 +569,14 @@ Tk_MenuObjCmd(
while (topLevelListPtr != NULL) {
/*
- * Need to get the next pointer first. Tk_SetWindowMenuBar changes
+ * Need to get the next pointer first. Tk_SetWindowMenubar changes
* the list, so that the next pointer is different after calling
* it.